@@ -216,16 +216,58 @@ static void find_child_at (GtkWidget * widget,
 
 #if 0
 /* This is probably what we should have used to get all button presses and
-   releases on widget etc. But it may be too awkward to change now. */
+   releases on widget etc. But it may be too awkward to change now.
+   Note that we'll also get all signals for Glade's own widgets.
+
+   Actually I don't think this would help that much, since emission hooks
+   are run after RUN_FIRST class handlers, and you can't stop a signal from
+   them.
+
+   So we'd have to substitute a Glade function for all 'button_press' class
+   functions, and only call the original class functions when appropriate.
+   We'd still need to be able to stop signal handlers. Hmm. */
 static gboolean
-event_watcher (GSignalInvocationHint *ihint,
-	       guint                  n_param_values,
-	       const GValue          *param_values,
-	       gpointer               data)
+button_press_event_hook (GSignalInvocationHint *ihint,
+			 guint                  n_param_values,
+			 const GValue          *param_values,
+			 gpointer               data)
 {
-  g_print ("Watch: \"%s\" emitted for %s\n",
+  GtkWidget *widget;
+  GdkEventButton *event;
+
+  widget = g_value_get_object (param_values + 0);
+  event = g_value_get_boxed (param_values + 1);
+
+  g_print ("Watch: \"%s\" emitted for %s at %g,%g\n",
 	   gtk_signal_name (ihint->signal_id),
-	   gtk_type_name (GTK_OBJECT_TYPE (g_value_get_object (param_values + 0))));
+	   gtk_type_name (GTK_OBJECT_TYPE (widget)),
+	   event->x, event->y);
+
+  /* Test: try to stop the emission. Can't! */
+  /*g_signal_stop_emission (widget, ihint->signal_id, 0);*/
+
+
+  /* If we return FALSE our emission hook is removed. */
+  return TRUE;
+}
+
+
+static gboolean
+button_release_event_hook (GSignalInvocationHint *ihint,
+			   guint                  n_param_values,
+			   const GValue          *param_values,
+			   gpointer               data)
+{
+  GtkWidget *widget;
+  GdkEvent *event;
+
+  widget = g_value_get_object (param_values + 0);
+  event = g_value_get_boxed (param_values + 1);
+
+  g_print ("Watch: \"%s\" emitted for %s type:%i\n",
+	   gtk_signal_name (ihint->signal_id),
+	   gtk_type_name (GTK_OBJECT_TYPE (widget)),
+	   event->type);
 
   /* If we return FALSE our emission hook is removed. */
   return TRUE;
@@ -235,10 +277,6 @@ event_watcher (GSignalInvocationHint *ihint,
 void
 editor_init ()
 {
-#if 0
-  guint signal_id;
-#endif
-
   /* Create all cursors needed */
   cursor_selector = gdk_cursor_new (GDK_TOP_LEFT_ARROW);
   cursor_add_widget = gdk_cursor_new (GDK_PLUS);
@@ -250,11 +288,19 @@ editor_init ()
   cursor_bottom_right = gdk_cursor_new (GDK_BOTTOM_RIGHT_CORNER);
 
 #if 0
-  /* FIXME: Test: Add emission hooks. */
-  signal_id = gtk_signal_lookup ("button_press_event", GTK_TYPE_WIDGET);
-  g_signal_add_emission_hook (signal_id, 0, event_watcher, NULL, NULL);
-  signal_id = gtk_signal_lookup ("button_release_event", GTK_TYPE_WIDGET);
-  g_signal_add_emission_hook (signal_id, 0, event_watcher, NULL, NULL);
+ {
+   guint button_press_signal_id, button_release_signal_id;
+
+   button_press_signal_id = gtk_signal_lookup ("button_press_event",
+					       GTK_TYPE_WIDGET);
+   g_signal_add_emission_hook (button_press_signal_id, 0,
+			       button_press_event_hook, NULL, NULL);
+   
+   button_release_signal_id = gtk_signal_lookup ("button_release_event",
+						 GTK_TYPE_WIDGET);
+   g_signal_add_emission_hook (button_release_signal_id, 0,
+			       button_release_event_hook, NULL, NULL);
+ }
 #endif
 }
 
@@ -1056,6 +1102,32 @@ editor_get_event_widget (GtkWidget *widget, GdkWindow *window, gint x, gint y,
 }
 
 
+/* We use the "event" signal since it is emitted before the "button_press"
+   or "button_release" signal is emitted. This means we can catch it and
+   stop the normal signal handlers. */
+static gint
+editor_on_event (GtkWidget * signal_widget,
+		 GdkEvent * event,
+		 gpointer user_data)
+{
+#if 0
+  g_print ("In editor_on_event widget: %s\n",
+	   gtk_widget_get_name (signal_widget));
+#endif
+
+  if (event->type == GDK_BUTTON_PRESS
+      || event->type == GDK_2BUTTON_PRESS
+      || event->type == GDK_3BUTTON_PRESS)
+    return editor_on_button_press (signal_widget, (GdkEventButton*) event,
+				   user_data);
+
+  if (event->type == GDK_BUTTON_RELEASE)
+    return editor_on_button_release (signal_widget, event, user_data);
+
+  return FALSE;
+}
+
+
 static gint
 editor_on_button_press (GtkWidget * signal_widget,
 			GdkEventButton * event,
@@ -1085,9 +1157,11 @@ editor_on_button_press (GtkWidget * signal_widget,
 	  gboolean handled;
 	  MSG ("...Selecting widget");
 	  handled = editor_select_widget (widget, event, x, y);
+#if 0
 	  if (handled)
 	    gtk_signal_emit_stop_by_name (GTK_OBJECT (signal_widget),
 					  "button_press_event");
+#endif
 	  return handled;
 	}
 #ifdef USE_GNOME
@@ -1098,23 +1172,30 @@ editor_on_button_press (GtkWidget * signal_widget,
 #endif
 	{
 	  add_widget_to_fixed (widget, x, y);
+#if 0
 	  gtk_signal_emit_stop_by_name (GTK_OBJECT (signal_widget),
 					"button_press_event");
+#endif
 	  return TRUE;
 	}
       else if (GB_IS_PLACEHOLDER (widget))
 	{
 	  placeholder_replace (widget);
+#if 0
 	  gtk_signal_emit_stop_by_name (GTK_OBJECT (signal_widget),
 					"button_press_event");
+#endif
 	  return TRUE;
 	}
 #if GLADE_SUPPORTS_GTK_PACKER
       else if (GTK_IS_PACKER (widget))
 	{
 	  add_widget_to_container (widget);
+#if 0
 	  gtk_signal_emit_stop_by_name (GTK_OBJECT (signal_widget),
 					"button_press_event");
+#endif
+	  return TRUE;
 	}
 #endif
       else
@@ -1141,8 +1222,10 @@ editor_on_button_press (GtkWidget * signal_widget,
   else if (event->button == 3)
     {
       gb_widget_show_popup_menu (widget, event);
+#if 0
       gtk_signal_emit_stop_by_name (GTK_OBJECT (signal_widget),
 				    "button_press_event");
+#endif
       return TRUE;
     }
   return FALSE;
@@ -2166,10 +2249,14 @@ editor_on_widget_realize (GtkWidget *widget, gpointer data)
 void
 editor_add_mouse_signals_to_existing (GtkWidget * widget)
 {
+  gtk_signal_connect (GTK_OBJECT (widget), "event",
+		      GTK_SIGNAL_FUNC (editor_on_event), NULL);
+#if 0
   gtk_signal_connect (GTK_OBJECT (widget), "button_press_event",
 		      GTK_SIGNAL_FUNC (editor_on_button_press), NULL);
   gtk_signal_connect (GTK_OBJECT (widget), "button_release_event",
 		      GTK_SIGNAL_FUNC (editor_on_button_release), NULL);
+#endif
 }
 
 
@@ -2197,7 +2284,9 @@ static void
 add_mouse_signals_recursive (GtkWidget *widget, gpointer data)
 {
 #if 0
-  g_print ("Adding mouse signals to:%s (%p)\n", gtk_widget_get_name (widget),
+  g_print ("Adding mouse signals to:%s (%s, %p)\n",
+	   gtk_widget_get_name (widget),
+	   gtk_type_name (GTK_OBJECT_TYPE (widget)),
 	   widget);
 #endif
 
@@ -2230,10 +2319,14 @@ add_mouse_signals_recursive (GtkWidget *widget, gpointer data)
 	}
     }
 
+  gtk_signal_connect (GTK_OBJECT (widget), "event",
+		      GTK_SIGNAL_FUNC (editor_on_event), NULL);
+#if 0
   gtk_signal_connect (GTK_OBJECT (widget), "button_press_event",
 		      GTK_SIGNAL_FUNC (editor_on_button_press), NULL);
   gtk_signal_connect (GTK_OBJECT (widget), "button_release_event",
 		      GTK_SIGNAL_FUNC (editor_on_button_release), NULL);
+#endif
 
   /* We connect to these so we can stop widgets getting them while we are
      dragging/resizing. It stops widgets changing state, i.e. normal/active
@@ -2928,7 +3021,9 @@ editor_on_key_press_event (GtkWidget * widget, GdkEventKey * event,
 
   if (handled)
     {
+#if 0
       gtk_signal_emit_stop_by_name (GTK_OBJECT (widget), "key_press_event");
+#endif
       return TRUE;
     }
   return FALSE;
@@ -3045,6 +3140,13 @@ delete_placeholder (GtkWidget * placeholder)
       return;
     }
 
+  /* If the parent is a toolitem, delete that. */
+  if (GTK_IS_TOOL_ITEM (parent))
+    {
+      gtk_container_remove (GTK_CONTAINER (parent->parent), parent);
+      return;
+    }
+
   /* Widgets with these parents can all be deleted OK */
   if (GTK_IS_TOOLBAR (parent)
 #if GLADE_SUPPORTS_GTK_TREE
