@@ -43,6 +43,9 @@ extern "C" {
 #define GLADE_GTK_GETTEXT_PACKAGE	"gtk20"
 
 
+  /* The index of the dialog hint in GbTypeHintChoices. */
+#define GLADE_TYPE_HINT_DIALOG_INDEX	1
+
 /* This is the error margin we use for floating-point comparisons. */
 #define GLADE_EPSILON	0.000001
 
