@@ -103,10 +103,11 @@ gb_widget_write_source (GtkWidget * widget,
 	      /* We don't create standard widgets for Bonobo controls, for
 		 now. There may be a better way to get default values for
 		 them. */
-	      else if (!BONOBO_IS_WIDGET (widget))
+	      else if (!data->standard_widget && !BONOBO_IS_WIDGET (widget))
 		data->standard_widget = GTK_WIDGET (g_object_newv (gtk_type_from_name (class_id), 0, NULL));
 #else
-	      data->standard_widget = GTK_WIDGET (g_object_newv (gtk_type_from_name (class_id), 0, NULL));
+	      if (!data->standard_widget)
+		data->standard_widget = GTK_WIDGET (g_object_newv (gtk_type_from_name (class_id), 0, NULL));
 #endif
 
 	      if (data->standard_widget)
@@ -330,8 +331,7 @@ gb_widget_write_standard_source (GtkWidget * widget,
       if (can_focus)
 	source_add (data, "  GTK_WIDGET_SET_FLAGS (%s, GTK_CAN_FOCUS);\n",
 		    data->wname);
-      /* SPECIAL CODE: toolbar widgets can't get focus by default. */
-      else if (!gb_toolbar_is_toolbar_button (widget))
+      else
 	source_add (data, "  GTK_WIDGET_UNSET_FLAGS (%s, GTK_CAN_FOCUS);\n",
 		    data->wname);
     }
@@ -365,13 +365,26 @@ gb_widget_write_standard_source (GtkWidget * widget,
 	data->default_widget = g_strdup (data->wname);
     }
 
-  /* SPECIAL CODE: toolbar children use the toolbar's tooltips. */
-  if (wdata->tooltip && (!widget->parent || !GTK_IS_TOOLBAR (widget->parent)))
+  if (wdata->tooltip)
     {
       data->need_tooltips = TRUE;
-      source_add (data, "  gtk_tooltips_set_tip (tooltips, %s, %s, NULL);\n",
-		  data->wname,
-		  source_make_string (wdata->tooltip, data->use_gettext));
+
+      /* GtkToolItem subclasses use a special function, since otherwise they
+	 wouldn't work as they don't have a window. */
+      if (GTK_IS_TOOL_ITEM (widget))
+	{
+	  source_add (data,
+		      "  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (%s), tooltips, %s, NULL);\n",
+		      data->wname,
+		      source_make_string (wdata->tooltip, data->use_gettext));
+	}
+      else
+	{
+	  source_add (data,
+		      "  gtk_tooltips_set_tip (tooltips, %s, %s, NULL);\n",
+		      data->wname,
+		      source_make_string (wdata->tooltip, data->use_gettext));
+	}
     }
 
   if (!GTK_WIDGET_NO_WINDOW (widget))
