@@ -268,6 +268,10 @@ struct _GbWidget
   gint		  properties_page_number;	/* Used internally */
   gint		  child_properties_page_number;	/* Used internally */
 
+  /* We need a pixbuf rather than GdkPixmap for the tree. This is only
+     created when needed for now. */
+  GdkPixbuf	 *pixbuf;
+
   /* Creates a new widget of the particular class, or possibly shows a dialog
      for the user to set options before creating the widget (but it must not
      do this when loading an XML file, i.e. when the action is GB_LOADING). */
