@@ -35,6 +35,7 @@ static GbWidget gbwidget;
 static gchar *StockButton = "CheckButton|GtkButton::stock_button";
 static gchar *Label = "CheckButton|GtkButton::label";
 static gchar *Icon = "CheckButton|GtkButton::icon";
+static gchar *FocusOnClick = "CheckButton|GtkButton::focus_on_click";
 
 /* This is only used for normal/stock buttons, not special toolbar buttons,
    as the toolbar has its own relief setting. */
@@ -98,6 +99,7 @@ gb_check_button_create_properties (GtkWidget * widget, GbWidgetCreateArgData *
 		     _("If the button is shown in an inconsistent state"));
   property_add_bool (Indicator, _("Indicator:"),
 		     _("If the indicator is always drawn"));
+  property_add_bool (FocusOnClick, _("Focus On Click:"), _("If the button grabs focus when it is clicked"));
 }
 
 
@@ -110,7 +112,7 @@ static void
 gb_check_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 {
   gb_button_get_standard_properties (widget, data, StockButton, Label, Icon,
-				     Relief);
+				     Relief, FocusOnClick);
 
   gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
   gb_widget_output_bool (data, Inconsistent,
@@ -131,7 +133,7 @@ gb_check_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   gboolean state, indicator, inconsistent;
 
   gb_button_set_standard_properties (widget, data, StockButton, Label, Icon,
-				     Relief);
+				     Relief, FocusOnClick);
 
   state = gb_widget_input_bool (data, State);
   if (data->apply)
