@@ -94,6 +94,9 @@ gb_color_selection_dialog_new (GbWidgetNewData * data)
 			 data->action == GB_CREATING ? "color_selection" : NULL);
   gb_widget_set_child_name (colorsel->colorsel, GladeChildColorSelection);
 
+  gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return new_widget;
 }
 
