@@ -105,6 +105,9 @@ create_dialog (const gchar *title, GbWidgetAction action)
   gb_widget_set_child_name (GTK_DIALOG (new_widget)->action_area,
 			    GladeChildDialogActionArea);
 
+  gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return new_widget;
 }
 
