@@ -154,7 +154,7 @@ gb_entry_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 
   editable = gb_widget_input_bool (data, Editable);
   if (data->apply)
-    gtk_entry_set_editable (GTK_ENTRY (widget), editable);
+    gtk_editable_set_editable (GTK_EDITABLE (widget), editable);
 
   visible = gb_widget_input_bool (data, Visible);
   if (data->apply)
@@ -232,21 +232,18 @@ gb_entry_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   if (data->create_widget)
     {
-      if (max_len)
-	{
-	  source_add (data, "  %s = gtk_entry_new_with_max_length (%d);\n",
-		      data->wname, max_len);
-	}
-      else
-	{
-	  source_add (data, "  %s = gtk_entry_new ();\n", data->wname);
-	}
+      source_add (data, "  %s = gtk_entry_new ();\n", data->wname);
     }
   gb_widget_write_standard_source (widget, data);
 
+  if (max_len)
+    {
+      source_add (data, "  gtk_entry_set_max_length (GTK_ENTRY (%s), %d);\n",
+		  data->wname, max_len);
+    }
   if (!GTK_ENTRY (widget)->editable)
     {
-      source_add (data, "  gtk_entry_set_editable (GTK_ENTRY (%s), FALSE);\n",
+      source_add (data, "  gtk_editable_set_editable (GTK_EDITABLE (%s), FALSE);\n",
 		  data->wname);
     }
   if (!GTK_ENTRY (widget)->visible)
