@@ -343,7 +343,7 @@ gb_notebook_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
   gboolean show_tabs, show_border, scrollable, popups;
   gchar *tab_pos;
-  gint tab_border, i, num_pages;
+  gint i, num_pages;
   GtkWidget *new_label;
 
   show_tabs = gb_widget_input_bool (data, ShowTabs);
