@@ -106,6 +106,8 @@ gb_radio_menu_item_create_properties (GtkWidget * widget, GbWidgetCreateArgData
   property_add_combo (Group, _("Group:"),
 		      _("The radio menu item group (the default is all radio menu items with the same parent)"),
 		      NULL);
+  /* The Group property is only used for loading and saving at present. */
+  property_set_visible (Group, FALSE);
 }
 
 
