@@ -159,11 +159,25 @@ gb_toolbar_add_child (GtkWidget *widget, GtkWidget *child, GbWidgetSetArgData *d
       gtk_toolbar_insert (GTK_TOOLBAR (widget),
 			  GTK_TOOL_ITEM (toolitem), -1);
     }
-  else
+  /* GtkToolItems can just be added as they are. */
+  else if (GTK_IS_TOOL_ITEM (child))
     {
       gtk_toolbar_insert (GTK_TOOLBAR (widget),
 			  GTK_TOOL_ITEM (child), -1);
     }
+  /* Any other widgets are from the old GTK+ 2.2 files, and we need to insert
+     a GtkToolItem. */
+  else
+    {
+      GtkWidget *toolitem = gb_widget_new_full ("GtkToolItem", FALSE,
+						NULL, NULL, 0, 0, NULL,
+						GB_LOADING, data);
+      gtk_toolbar_insert (GTK_TOOLBAR (widget),
+			  GTK_TOOL_ITEM (toolitem), -1);
+      tree_add_widget (toolitem);
+
+      gtk_container_add (GTK_CONTAINER (toolitem), child);
+    }
 }
 
 
