@@ -80,6 +80,8 @@ static const gchar *GbTypeSymbols[] =
   "GTK_WINDOW_POPUP"
 };
 
+/* If you change these arrays be sure to make sure
+   GLADE_TYPE_HINT_DIALOG_INDEX is up to date in gb.h. */
 static const gchar *GbTypeHintChoices[] =
 {"Normal", "Dialog", "Menu", "Toolbar", "Splash Screen", "Utility",
  "Dock", "Desktop", NULL};
