@@ -129,7 +129,8 @@ create_widget_info(GladeInterface *interface, const xmlChar **attrs)
     }
     if (info->class == NULL || info->name == NULL)
 	g_warning("<widget> element missing required attributes!");
-    g_hash_table_insert(interface->names, info->name, info);
+    if (info->name)
+	g_hash_table_insert(interface->names, info->name, info);
     return info;
 }
 
@@ -1111,6 +1112,8 @@ glade_interface_destroy(GladeInterface *interface)
 GladeInterface *
 glade_parser_parse_file(const gchar *file, const gchar *domain)
 {
+    int old_substitute_entities;
+    int result;
     GladeParseState state = { 0 };
 
     state.interface = NULL;
@@ -1119,7 +1122,11 @@ glade_parser_parse_file(const gchar *file, const gchar *domain)
     else
 	state.domain = textdomain(NULL);
 
-    if (xmlSAXUserParseFile(&glade_parser, &state, file) < 0) {
+    old_substitute_entities = xmlSubstituteEntitiesDefault(1);
+    result = xmlSAXUserParseFile(&glade_parser, &state, file);
+    xmlSubstituteEntitiesDefault(old_substitute_entities);
+    
+    if (result < 0) {
 	g_warning("document not well formed!");
 	if (state.interface)
 	    glade_interface_destroy (state.interface);
@@ -1152,6 +1159,8 @@ glade_parser_parse_file(const gchar *file, const gchar *domain)
 GladeInterface *
 glade_parser_parse_buffer(const gchar *buffer, gint len, const gchar *domain)
 {
+    int old_substitute_entities;
+    int result;
     GladeParseState state = { 0 };
 
     state.interface = NULL;
@@ -1160,7 +1169,11 @@ glade_parser_parse_buffer(const gchar *buffer, gint len, const gchar *domain)
     else
 	state.domain = textdomain(NULL);
 
-    if (xmlSAXUserParseMemory(&glade_parser, &state, buffer, len) < 0) {
+    old_substitute_entities = xmlSubstituteEntitiesDefault(1);
+    result = xmlSAXUserParseMemory(&glade_parser, &state, buffer, len);
+    xmlSubstituteEntitiesDefault(old_substitute_entities);
+
+    if (result < 0) {
 	g_warning("document not well formed!");
 	if (state.interface)
 	    glade_interface_destroy (state.interface);
