@@ -528,6 +528,8 @@ glade_palette_set_show_gnome_widgets (GladePalette *palette,
       set_button_visibility (sect, "GnomeMessageBox", show_gnome);
       set_button_visibility (sect, "GnomePropertyBox", show_gnome);
       set_button_visibility (sect, "GnomePixmap", show_gnome);
+      set_button_visibility (sect, "GnomeColorPicker", show_gnome);
+      set_button_visibility (sect, "GnomeFontPicker", show_gnome);
     }
 }
 
