@@ -47,10 +47,10 @@ static void glade_project_view_select_component (GladeProjectView *project_view,
 						 GdkEventButton   *bevent,
 						 gpointer	   data);
 
-guint
+GType
 glade_project_view_get_type (void)
 {
-  static guint glade_project_view_type = 0;
+  static GType glade_project_view_type = 0;
 
   if (!glade_project_view_type)
     {
