@@ -21,7 +21,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkfilesel.h>
+#include <gtk/gtkfilechooserdialog.h>
 #include <gtk/gtkhbbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkimagemenuitem.h>
@@ -61,6 +61,17 @@ static GtkWidget *property_editor_item = NULL;
 static GtkWidget *widget_tree_item = NULL;
 static GtkWidget *clipboard_item = NULL;
 
+/* stuff for opening a file when dragged into glade */
+enum
+{
+  TARGET_URI_LIST
+};
+
+static GtkTargetEntry drop_types[] =
+{
+  {"text/uri-list", 0, TARGET_URI_LIST}
+};
+
 
 static gboolean glade_project_window_delete_event (GtkWidget *widget,
 						   GdkEvent *event,
@@ -74,7 +85,14 @@ static void glade_project_window_on_new_project_ok (GladeProjectWindow *project_
 static void glade_project_window_on_open_project (GtkWidget *widget,
 					       gpointer   data);
 static void glade_project_window_real_open_project (GtkWidget          *widget,
+						    gint		response_id,
 						    GladeProjectWindow *project_window);
+
+static void glade_project_window_drag_data_received (GtkWidget *widget,
+                                                     GdkDragContext *context,
+                                                     gint x, gint y,
+                                                     GtkSelectionData *selection_data,
+                                                     guint info, guint time, gpointer data);
 #if 0
 static void glade_project_window_show_loading_errors (GladeProjectWindow *project_window,
 						      GList		 *errors);
@@ -93,6 +111,7 @@ static void glade_project_window_on_save_project_as (GtkWidget *widget,
 						     gpointer   data);
 static void glade_project_window_save_project_as (GladeProjectWindow *project_window);
 static void glade_project_window_save_as_callback (GtkWidget          *widget,
+						   gint		   response_id,
 						   GladeProjectWindow *project_window);
 #endif
 static gboolean glade_project_window_real_save_project (GladeProjectWindow *project_window,
@@ -169,14 +188,6 @@ glade_project_window_show_help_doc (const gchar *docname,
 }
 
 
-static void
-glade_project_window_show_turbo_start (GtkWidget *menuitem,
-				       gpointer data)
-{
-  glade_project_window_show_help_doc ("glade-turbo-start", menuitem);
-}
-
-
 static void
 glade_project_window_show_glade_faq (GtkWidget *menuitem,
 				     gpointer data)
@@ -323,13 +334,6 @@ static GnomeUIInfo SettingsMenu[] =
 static GnomeUIInfo HelpMenu[] =
 {
   GNOMEUIINFO_HELP ("glade-user-guide"),
-  {
-    GNOME_APP_UI_ITEM, N_("_Turbo Start"),
-    N_("View the turbo start guide"),
-    glade_project_window_show_turbo_start, NULL, NULL,
-    GNOME_APP_PIXMAP_NONE, NULL,
-    0, 0, NULL
-  },
   {
     GNOME_APP_UI_ITEM, N_("_FAQ"),
     N_("View the Glade FAQ"),
@@ -427,6 +431,15 @@ glade_project_window_new (void)
 			    GTK_SIGNAL_FUNC (glade_project_window_key_press_event),
 			    NULL);
 
+  /* support for opening a file by dragging onto the project window */
+  gtk_drag_dest_set (project_window->window,
+                     GTK_DEST_DEFAULT_ALL,
+                     drop_types, G_N_ELEMENTS (drop_types),
+                     GDK_ACTION_COPY | GDK_ACTION_MOVE);
+
+  g_signal_connect (G_OBJECT (project_window->window), "drag-data-received",
+                    G_CALLBACK (glade_project_window_drag_data_received), NULL);
+
   gnome_app_create_menus (GNOME_APP (project_window->window), MainMenu);
 
   /* Set the states of the toggle items. */
@@ -1110,40 +1123,38 @@ glade_project_window_on_open_project (GtkWidget *widget,
   project_window = get_glade_project_window (widget);
   g_return_if_fail (project_window != NULL);
 
-  filesel = gtk_file_selection_new (_("Open Project"));
+  filesel = gtk_file_chooser_dialog_new (_("Open Project"),
+					 GTK_WINDOW (project_window->window),
+					 GTK_FILE_CHOOSER_ACTION_OPEN,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+					 NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
-  gtk_window_set_wmclass (GTK_WINDOW (filesel), "open_project", "Glade");  
-  if (GTK_IS_WINDOW (project_window->window))
-    gtk_window_set_transient_for (GTK_WINDOW (filesel),
-				  GTK_WINDOW (project_window->window));
+
+  g_signal_connect (filesel, "response",
+		    GTK_SIGNAL_FUNC (glade_project_window_real_open_project),
+		    project_window);
+
   if (project_window->current_directory)
     glade_util_set_file_selection_filename (filesel, project_window->current_directory);
 
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-		      "clicked",
-		      GTK_SIGNAL_FUNC (glade_project_window_real_open_project),
-		      project_window);
-  gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (filesel));
-  gtk_signal_connect (GTK_OBJECT (filesel), "key_press_event",
-		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
-		      GINT_TO_POINTER (GladeEscDestroys));
   gtk_widget_show (filesel);
 }
 
 
 static void
-glade_project_window_real_open_project (GtkWidget          *widget,
+glade_project_window_real_open_project (GtkWidget          *filesel,
+					gint		    response_id,
 					GladeProjectWindow *project_window)
 {
-  GtkWidget *filesel;
-  gchar *filename;
-
-  filesel = gtk_widget_get_toplevel (widget);
-  filename = glade_util_get_file_selection_filename (filesel);
-  glade_project_window_open_project (project_window, filename);
-  g_free (filename);
+  if (response_id == GTK_RESPONSE_OK)
+    {
+      gchar *filename = glade_util_get_file_selection_filename (filesel);
+      if (filename)
+	glade_project_window_open_project (project_window, filename);
+      g_free (filename);
+    }
   gtk_widget_destroy (filesel);
 }
 
@@ -1197,6 +1208,44 @@ glade_project_window_open_project (GladeProjectWindow *project_window,
 }
 
 
+static void
+glade_project_window_drag_data_received (GtkWidget *widget,
+                                         GdkDragContext *context,
+                                         gint x, gint y,
+                                         GtkSelectionData *selection_data,
+                                         guint info, guint time, gpointer data)
+{
+  GladeProjectWindow *project_window;
+  gchar *uri_list;
+  GList *list = NULL;
+
+  if (info != TARGET_URI_LIST)
+    return;
+
+  /*
+   * Mmh... it looks like on Windows selection_data->data is not
+   * NULL terminated, so we need to make sure our local copy is.
+   */
+  uri_list = g_new (gchar, selection_data->length + 1);
+  memcpy (uri_list, selection_data->data, selection_data->length);
+  uri_list[selection_data->length] = 0;
+
+  project_window = get_glade_project_window (widget);
+  g_return_if_fail (project_window != NULL);
+
+  /* For now, if more than a file is dragged into glade we actually
+   * only try the first one... we can open only one anyway.
+   */
+  list = glade_util_uri_list_parse (uri_list);
+  if (list->data)
+    glade_project_window_open_project (project_window, list->data);
+
+  /* we can now free each string in the list */
+  g_list_foreach (list, (GFunc) g_free, NULL);
+  g_list_free (list);
+}
+
+
 /* This shows the errors in a dialog, and frees them. */
 /* Currently unused, since we switched to using libxml. */
 #if 0
@@ -1428,51 +1477,51 @@ glade_project_window_save_project_as (GladeProjectWindow *project_window)
 {
   GtkWidget *filesel;
 
-  filesel = gtk_file_selection_new (_("Save Project"));
+  filesel = gtk_file_chooser_dialog_new (_("Save Project"),
+					 GTK_WINDOW (project_window->window),
+					 GTK_FILE_CHOOSER_ACTION_SAVE,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					 NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
-  gtk_window_set_wmclass (GTK_WINDOW (filesel), "save_project", "Glade");  
-  if (GTK_IS_WINDOW (project_window->window))
-    gtk_window_set_transient_for (GTK_WINDOW (filesel),
-				  GTK_WINDOW (project_window->window));
+ 
+  g_signal_connect (options->filesel, "response",
+		    GTK_SIGNAL_FUNC (glade_project_window_save_as_callback),
+		    project_window);
+
   if (project_window->current_directory)
     glade_util_set_file_selection_filename (filesel, project_window->current_directory);
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-		      "clicked",
-		      GTK_SIGNAL_FUNC (glade_project_window_save_as_callback),
-		      project_window);
-  gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (filesel));
-  gtk_signal_connect (GTK_OBJECT (filesel), "key_press_event",
-		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
-		      GINT_TO_POINTER (GladeEscDestroys));
+
   gtk_widget_show (filesel);
 }
 
 
 static void
-glade_project_window_save_as_callback (GtkWidget          *widget,
+glade_project_window_save_as_callback (GtkWidget          *filesel,
+				       gint		   response_id,
 				       GladeProjectWindow *project_window)
 {
   GladeProject *project;
-  GtkWidget *filesel;
   gchar *filename;
-  gboolean saved;
 
-  filesel = gtk_widget_get_toplevel (widget);
-  filename = glade_util_get_file_selection_filename (filesel);
-
-  g_free (project_window->current_directory);
-  project_window->current_directory = glade_util_dirname (filename);
-
-  project = glade_project_view_get_project (GLADE_PROJECT_VIEW (project_window->project_view));
-  if (project)
+  if (response_id == GTK_RESPONSE_OK)
     {
-      glade_project_set_xml_filename (project, filename);
-      glade_project_window_real_save_project (project_window, TRUE);
+      filename = glade_util_get_file_selection_filename (filesel);
+
+      g_free (project_window->current_directory);
+      project_window->current_directory = glade_util_dirname (filename);
+
+      project = glade_project_view_get_project (GLADE_PROJECT_VIEW (project_window->project_view));
+      if (project)
+	{
+	  glade_project_set_xml_filename (project, filename);
+	  glade_project_window_real_save_project (project_window, TRUE);
+	}
+      g_free (filename);
     }
+
   gtk_widget_destroy (filesel);
-  g_free (filename);
 }
 #endif
 
