@@ -32,6 +32,7 @@ static GbWidget gbwidget;
 
 static gchar *HRefURL = "GnomeHRef::url";
 static gchar *HRefLabel = "GnomeHRef::label";
+static gchar *FocusOnClick = "GnomeHRef|GtkButton::focus_on_click";
 
 
 /******
@@ -66,6 +67,7 @@ gb_gnome_href_create_properties (GtkWidget * widget, GbWidgetCreateArgData * dat
 		       _("The URL to display when the button is clicked"));
   property_add_text (HRefLabel, _("Label:"),
 		     _("The text to display in the button"), 2);
+  property_add_bool (FocusOnClick, _("Focus On Click:"), _("If the button grabs focus when it is clicked"));
 }
 
 
@@ -88,6 +90,9 @@ gb_gnome_href_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 
   g_free (uri);
   g_free (label);
+
+  gb_widget_output_bool (data, FocusOnClick,
+			 gtk_button_get_focus_on_click (GTK_BUTTON (widget)));
 }
 
 
@@ -100,6 +105,7 @@ static void
 gb_gnome_href_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
   gchar *url, *label_text;
+  gboolean focus_on_click;
 
   url = gb_widget_input_string (data, HRefURL);
   if (data->apply)
@@ -110,6 +116,10 @@ gb_gnome_href_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
     gnome_href_set_text (GNOME_HREF (widget), label_text);
   if (data->action == GB_APPLYING)
     g_free (label_text);
+
+  focus_on_click = gb_widget_input_bool (data, FocusOnClick);
+  if (data->apply)
+    gtk_button_set_focus_on_click (GTK_BUTTON (widget), focus_on_click);
 }
 
 
@@ -155,6 +165,13 @@ gb_gnome_href_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
     }
 
   gb_widget_write_standard_source (widget, data);
+
+  if (!gtk_button_get_focus_on_click (GTK_BUTTON (widget)))
+    {
+      source_add (data,
+		  "  gtk_button_set_focus_on_click (GTK_BUTTON (%s), FALSE);\n",
+		  data->wname);
+    }
 }
 
 
